Package org.openrewrite
Interface Tree
-
- All Known Subinterfaces:
Marker,SearchResult,SourceFile
- All Known Implementing Classes:
DeclarativeNamedStyles,GitProvenance,Markers,NamedStyles,PlainText,RecipeSearchResult
public interface Tree
-
-
Method Summary
All Methods Static Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default <R extends Tree,P>
Raccept(TreeVisitor<R,P> v, P p)Supports polymorphic visiting viaTreeVisitor.visit(Tree, Object).java.util.UUIDgetId()An id that can be used to identify a particular AST element, even after transformations have taken place on it<P> booleanisAcceptable(TreeVisitor<?,P> v, P p)Checks the supplied argument to see if the supplied visitor and its context would be valid arguments to accept().default booleanisScope(@Nullable Tree tree)default java.lang.Stringprint()<P> java.lang.Stringprint(TreePrinter<P> printer, P p)default <P> java.lang.Stringprint(P p)default java.lang.StringprintTrimmed()default <P> java.lang.StringprintTrimmed(TreePrinter<P> printer, P p)default <P> java.lang.StringprintTrimmed(P p)static java.util.UUIDrandomId()
-
-
-
Method Detail
-
randomId
static java.util.UUID randomId()
-
getId
java.util.UUID getId()
An id that can be used to identify a particular AST element, even after transformations have taken place on it- Returns:
- A unique identifier
-
accept
@Nullable default <R extends Tree,P> R accept(TreeVisitor<R,P> v, P p)
Supports polymorphic visiting viaTreeVisitor.visit(Tree, Object). This is useful in cases where an AST type contains a field that is of a type with a hierarchy. The visitor doesn't have to figure out which visit method to call by using instanceof.- Type Parameters:
R- visitor return typeP- visit context type- Parameters:
v- visitorp- visit context- Returns:
- visitor result
-
isAcceptable
<P> boolean isAcceptable(TreeVisitor<?,P> v, P p)
Checks the supplied argument to see if the supplied visitor and its context would be valid arguments to accept(). Typically this involves checking that the visitor is of a type that operates on this kind of tree. e.g.: A Java Tree implementation would return true for JavaVisitors and false for MavenVisitors- Type Parameters:
P- the visitor's context argument- Returns:
- 'true' if the arguments to this function would be valid arguments to accept()
-
print
<P> java.lang.String print(TreePrinter<P> printer, P p)
-
print
default <P> java.lang.String print(P p)
-
print
default java.lang.String print()
-
printTrimmed
default <P> java.lang.String printTrimmed(TreePrinter<P> printer, P p)
-
printTrimmed
default <P> java.lang.String printTrimmed(P p)
-
printTrimmed
default java.lang.String printTrimmed()
-
-